#
# spec file for package dwarves
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dwarves
Version:        1.19
Release:        lp152.4.3.1
Summary:        DWARF utilities
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
URL:            http://acmel.wordpress.com/
#Git-Clone:	git://git.kernel.org/pub/scm/devel/pahole/pahole
#Git-Web:	http://git.kernel.org/cgit/devel/pahole/pahole.git
Source:         https://fedorapeople.org/~acme/dwarves/dwarves-%version.tar.xz
Source2:        https://fedorapeople.org/~acme/dwarves/dwarves-%version.tar.sign
Source9:        baselibs.conf
BuildRequires:  cmake
BuildRequires:  libdw-devel
%if 0%{?suse_version} < 1550
BuildRequires:  libebl-devel
%endif
BuildRequires:  libelf-devel
BuildRequires:  pkgconfig(zlib)
# Also known by its most prominent tool
Provides:       pahole = %version-%release

%description
dwarves is a set of tools that use the DWARF debugging information
inserted in ELF binaries by compilers such as GCC, used by well known
debuggers such as GDB, and more recent ones such as systemtap.

Utilities in the dwarves suite include pahole, that can be used to
find alignment holes in structs and classes in languages such as C,
C++, but not limited to these.

It also extracts other information such as CPU cacheline alignment,
helping pack those structures to achieve more cache hits.

A diff like tool, codiff can be used to compare the effects changes
in source code generate on the resulting binaries.

Another tool is pfunct, that can be used to find all sorts of
information about functions, inlines, decisions made by the compiler
about inlining, etc.

%package -n libdwarves1
Summary:        DWARF processing libraries of dwarves tools
Group:          System/Libraries
%if 0%{?suse_version} < 1550
Requires:       libebl-plugins
%endif

%description -n libdwarves1
This package contains the libdwarves shared library for the dwarves
toolset, providing processing for DWARF, a debugging data format
for ELF files.

dwarves is a set of tools that use the DWARF debugging information
inserted in ELF binaries by compilers such as GCC, used by well known
debuggers such as GDB, and more recent ones such as systemtap.

%package -n libdwarves-devel
Summary:        DWARF processing library development files
Group:          Development/Libraries/C and C++
Requires:       libdwarves1 = %version-%release

%description -n libdwarves-devel
This package contains the development files for libdwarves, a library
for processing DWARF, a debugging data format for ELF files.

%prep
%autosetup -p1

%build
sv="$PWD/lib.v"
echo "DWARVES_%version { global: *; };" >"$sv"
%cmake -DCMAKE_SHARED_LINKER_FLAGS:STRING="-Wl,--version-script=$sv"
%cmake_build

%install
%cmake_install

%post   -n libdwarves1 -p /sbin/ldconfig
%postun -n libdwarves1 -p /sbin/ldconfig

%files
%doc README NEWS
%_bindir/*
%_mandir/man*/*

%files -n libdwarves1
%_libdir/*.so.1*

%files -n libdwarves-devel
%_libdir/*.so
%_includedir/*
%_datadir/%name

%changelog
* Wed Jan  6 2021 Gary Ching-Pang Lin <glin@suse.com>
- Drop the version requirement of libdw-devel
  + DW_AT_alignment is defined in 1.19 so dwarves now is compatible
    with older libdw.
* Tue Nov 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.19
  * Support for split BTF.
  * Support cross-compiled ELF binaries with different endianness.
  * Support for showing typedefs for anonymous types, like structs,
    unions and enums.
* Tue Oct 27 2020 Jan Engelhardt <jengelh@inai.de>
- Add _service file / move to 1.18.g19 (863e6f0f)
  * btf_encoder: Ignore zero-sized ELF symbols
* Tue Oct 27 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.18_15g040fd7f (bsc#1177921):
  * btf_encoder: Support cross-compiled ELF binaries with different endianness
  * strings: use BTF's string APIs for strings management
  * strings: Rename strings.h to avoid clashing with /usr/include/strings.h
  * dwarf_loader: increase the size of lookup hash map
  * btf_encoder: revamp how per-CPU variables are encoded
  * btf_encoder: Discard CUs after BTF encoding
  * btf_encoder: Fix emitting __ARRAY_SIZE_TYPE__ as index range type
  * btf_encoder: Use libbpf APIs to encode BTF type info
  * btf_loader: Use libbpf to load BTF
  * dwarves: Expose and maintain active debug info loader operations
  * btf_encoder: detect BTF encoding errors and exit
  * libbpf: Update to latest libbpf version
  * dwarf_loader: Conditionally define DW_AT_alignment
  * pahole: Implement --packed
  * man-pages: Fix 'coimbine' typo
- remove libbpf-Fix-libbpf-hashmap-on-I-LP32-architectures.patch (upstream)
* Fri Oct  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.18
  * pahole now should be segfault free when handling gdb test
    suit DWARF files, including ADA, FORTRAN, rust and dwp
    compressed files (the latter is refused).
  * Bail out on partial units for now, avoiding segfaults.
- Drop
  dwarves-dwarf_loader-Ignore-entries-in-a-DW_TAG_partial_unit-for-now.patch,
  dwarves-dwarf_loader-Bail-out-at-DW_TAG_imported_unit-tags.patch
  (merged)
- Add forced ELF symvers because of ABI breaks
* Mon Sep 21 2020 Tom de Vries <tdevries@suse.com>
- Backport fixes for segfault when processing dwz-ed kernel
  [bsc#1176095,https://github.com/acmel/dwarves/issues/10].
  * dwarves-dwarf_loader-Bail-out-at-DW_TAG_imported_unit-tags.patch
  * dwarves-dwarf_loader-Ignore-entries-in-a-DW_TAG_partial_unit-for-now.patch
* Wed Sep  2 2020 Jiri Slaby <jslaby@suse.com>
- add libbpf-Fix-libbpf-hashmap-on-I-LP32-architectures.patch
* Tue May 19 2020 Ismail Dönmez <idonmez@suse.com>
- Don't require libebl-plugins on suse_version >= 1550
* Sun Mar 15 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.17
  * Support raw BTF as available in /sys/kernel/btf/vmlinux.
  * Make --find_pointers_to consider unions.
  * Make --contains and --find_pointers_to honour --unions.
  * Add support for finding pointers to void.
  * Make --contains and --find_pointers_to to work with base types.
* Mon Dec 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.16
  * btf_loader: Add support for BTF_KIND_FUNC
* Thu Jun 27 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.15
  * Avoid null dereference with NULL configs
  * Fixup printing "const" early with "const void"
  * Fix recursively printing named structs in --expand_types
* Wed May  1 2019 dsterba@suse.cz
- version 1.13
  - Use of the recently introduced BTF deduplication algorithm
  - Introduce a 'btfdiff' utility
  - Add a BTF loader, i.e. 'pahole -F btf' allows pretty printing of structs
    and unions in the same fashion as with DWARF info
  - Better union support
  - Infer __attribute__((__packed__)) when structs have no alignment holes
  - Support DWARF5's DW_AT_alignment
  - Add a '--compile' option to 'pfunct'
* Thu Aug 16 2018 jengelh@inai.de
- Update to new upstream release 1.12
  * Added a BTF (BPF Type Format) encoder
  * Initial support for DW_TAG_partial_unit
  * Print cacheline boundaries in multiple union members
  * Show offsets at union members
* Mon Mar 26 2018 jengelh@inai.de
- dwarves needs elfutils to have the EBL plugins available
  to carry out its work. [boo#1049871]
- Update to new upstream release 1.11
  * dwarf_loader: Do not stop processing after finding
    unsupported tags
  * dwarf_loader: Support DW_FORM_data{4,8} for reading class
    member offsets
  * dwarf_fprintf: Handle DW_TAG_GNU_call_site{_parameter}
  * dwarf_loader: Add support for DW_TAG_restrict_type
  * dwarf_loader: Initial support for DW_TAG_unspecified_type
- Remove dwarves-no-DW_TAG_mutable.patch (already applied)
* Wed Feb  1 2017 mpluskal@suse.com
- Use cmake macros
* Thu Jan 22 2015 dimstar@opensuse.org
- Add dwarves-no-DW_TAG_mutable.patch: Fix build with newer
  libdwarf versions: DW_TAG_mutable_type was a mistake in an early
  DWARFv3 draft and was removed in the final version.
* Wed Oct 15 2014 jengelh@inai.de
- Drop libdwarf dependency; it is not needed for build (libdw
  is used instead)
* Wed Jun  6 2012 jengelh@inai.de
- Update to new upstream release 1.10
  * Initial DWARF4 support
  * Add stubs for some new GNU tags
  * Fix a crash when pahole is called with -R -S
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
- Implement baselibs config
* Thu Aug 11 2011 jengelh@medozas.de
- Update to new upstream release 1.9
  * Add the "scncopy" tool - like object copy but tries not to change
  section content
  * pfunct: Introduce the -P option
  * dwarves fprintf: Add extra GNU tags
- Update group and description with something more detailed
- Remove redundant %%clean section
- Strip duplicate changelog
- Remove redundant manual requires on libraries
- Update URL to acme's new location
* Wed Apr 13 2011 mgorman@suse.de
- Remove %%debug_package directive which is breaking build
* Mon May  3 2010 lchiquitto@novell.com
- update to 1.8 release
* Fri Feb 29 2008 dmueller@suse.de
- update to 1.6 release
* Sat Dec  1 2007 dgollub@suse.de
- initial package of dwarves
